# SPDX-License-Identifier: AGPL-3.0-only
import parsecfg except Config
import types, strutils
from os import getEnv

proc get*[T](config: parseCfg.Config; section, key: string; default: T): T =
  let val = config.getSectionValue(section, key)
  if val.len == 0: return default

  when T is int: parseInt(val)
  elif T is bool: parseBool(val)
  elif T is string: val

proc getConfig*(path: string): (Config, parseCfg.Config) =
  var cfg = loadConfig(path)

  let conf = Config(
    # Server
    address: cfg.get("server", "address", "0.0.0.0"),
    port: cfg.get("server", "port", 8080),
    useHttps: cfg.get("server", "https", true),
    httpMaxConns: cfg.get("server", "httpMaxConnections", 100),
    staticDir: cfg.get("server", "staticDir", "./public"),
    accountsFile: cfg.get("server", "accountsFile", "./accounts.jsonl"),
    title: cfg.get("server", "title", "Nitter"),
    hostname: cfg.get("server", "hostname", "nitter.net"),

    # Cache
    listCacheTime: cfg.get("cache", "listMinutes", 120),
    rssCacheTime: cfg.get("cache", "rssMinutes", 10),

    redisHost: cfg.get("cache", "redisHost", "localhost"),
    redisPort: cfg.get("cache", "redisPort", 6379),
    redisConns: cfg.get("cache", "redisConnections", 20),
    redisMaxConns: cfg.get("cache", "redisMaxConnections", 30),
    redisPassword: cfg.get("cache", "redisPassword", ""),

    # Config
    hmacKey: cfg.get("config", "hmacKey", "secretkey"),
    base64Media: cfg.get("config", "base64Media", false),
    minTokens: cfg.get("config", "tokenCount", 10),
    enableRss: cfg.get("config", "enableRSS", true),
    enableDebug: cfg.get("config", "enableDebug", false),
    proxy: cfg.get("config", "proxy", ""),
    proxyAuth: cfg.get("config", "proxyAuth", "")
  )

  return (conf, cfg)


let configPath = getEnv("NITTER_CONF_FILE", "./nitter.conf")
let (cfg*, fullCfg*) = getConfig(configPath)
